@@ -73,9 +73,13 @@ typedef struct _SeedEngine
  * seed-engine.c
  */
 SeedEngine *seed_init (gint *argc, gchar ***argv);
+SeedEngine *
+seed_init_with_context (gint * argc, gchar *** argv, SeedGlobalContext context);
+
 SeedEngine *seed_init_with_context_group (gint *argc, gchar ***argv,
 					  SeedContextGroup group);
-
+SeedEngine *seed_init_with_context_and_group (gint * argc,gchar *** argv,
+					  SeedGlobalContext context, SeedContextGroup group);
 void seed_engine_destroy (SeedEngine *eng);
 
 SeedValue seed_simple_evaluate (SeedContext ctx,
@@ -144,6 +148,9 @@ gboolean seed_value_is_number (SeedContext ctx, SeedValue value);
 void seed_value_unprotect (SeedContext ctx, SeedValue value);
 void seed_value_protect (SeedContext ctx, SeedValue value);
 
+SeedValue seed_value_from_gvalue (SeedContext ctx,
+				  GValue * gval, SeedException * exception);
+
 gboolean seed_value_to_boolean (SeedContext ctx,
 				SeedValue val, SeedException * exception);
 
@@ -314,9 +321,7 @@ typedef gboolean (*SeedObjectSetPropertyCallback) (SeedContext ctx,
 						   SeedException * e);
 typedef gboolean (*SeedObjectDeletePropertyCallback) (SeedContext ctx,
 						      SeedObject object,
-						      SeedString
-						      property_name,
-						      SeedValue value,
+						      SeedString property_name,
 						      SeedException * e);
 /* TODO: Have to decide on accumulator API
 //typedef void (*SeedObjectGetPropertyNamesCallback) (SeedContext ctx, */
